@@ -8,9 +8,11 @@ import numpy as np
 from numpy.testing import assert_almost_equal
 
 import openmdao.api as om
-from openmdao.utils.assert_utils import assert_warning, assert_no_warning, assert_check_partials
+from openmdao.utils.assert_utils import assert_no_warning, assert_check_partials
+from openmdao.utils.testing_utils import use_tempdirs
 
 
+@use_tempdirs
 class TestBalanceComp(unittest.TestCase):
 
     def test_scalar_example(self):
@@ -119,7 +121,7 @@ class TestBalanceComp(unittest.TestCase):
 
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
-    def test_balance_comp_options_exclude_no_error(self):
+    def test_balance_comp_record_options(self):
 
         prob = om.Problem()
 
@@ -138,28 +140,9 @@ class TestBalanceComp(unittest.TestCase):
 
         prob.setup()
 
-        msg = ("Trying to record option 'guess_func' which cannot be pickled on system BalanceComp "
-               "(balance). Set 'recordable' to False. Skipping recording options for this system.")
-
-        with assert_no_warning(UserWarning, msg):
-            prob.run_model()
-
-        prob = om.Problem()
-
-        bal = om.BalanceComp()
-        bal.add_balance('x', val=1.0)
-
-        prob.model.add_subsystem(name='balance', subsys=bal)
-
-        recorder = om.SqliteRecorder('cases.sql')
-
-        prob.model.add_recorder(recorder)
-
-        bal.recording_options['options_excludes'] = ['guess_func']
-
-        prob.setup()
-
-        with assert_no_warning(UserWarning, msg):
+        # there should be no warnings wrt unpicklable 'guess_func' option,
+        # since 'recordable' has been set to False
+        with assert_no_warning(UserWarning):
             prob.run_model()
 
     def test_create_on_init_no_normalization(self):
@@ -209,7 +192,7 @@ class TestBalanceComp(unittest.TestCase):
 
         tgt = om.IndepVarComp(name='y_tgt', val=4*np.ones(n))
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': np.ones(n)}, y={'value': np.ones(n)})
+        exec_comp = om.ExecComp('y=x**2', x={'val': np.ones(n)}, y={'val': np.ones(n)})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
 
@@ -249,7 +232,7 @@ class TestBalanceComp(unittest.TestCase):
 
         tgt = om.IndepVarComp(name='y_tgt', val=1.7*np.ones(n))
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': np.ones(n)}, y={'value': np.ones(n)})
+        exec_comp = om.ExecComp('y=x**2', x={'val': np.ones(n)}, y={'val': np.ones(n)})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
 
@@ -291,7 +274,7 @@ class TestBalanceComp(unittest.TestCase):
 
         mult_ivc = om.IndepVarComp(name='mult', val=2.0*np.ones(n))
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': np.ones(n)}, y={'value': np.ones(n)})
+        exec_comp = om.ExecComp('y=x**2', x={'val': np.ones(n)}, y={'val': np.ones(n)})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
         prob.model.add_subsystem(name='mult_comp', subsys=mult_ivc, promotes_outputs=['mult'])
@@ -335,7 +318,7 @@ class TestBalanceComp(unittest.TestCase):
 
         tgt = om.IndepVarComp(name='y_tgt', val=4 * np.ones(n))
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': np.ones(n)}, y={'value': np.ones(n)})
+        exec_comp = om.ExecComp('y=x**2', x={'val': np.ones(n)}, y={'val': np.ones(n)})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
 
@@ -407,7 +390,7 @@ class TestBalanceComp(unittest.TestCase):
 
         tgt = om.IndepVarComp(name='y_tgt', val=4)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
 
@@ -447,7 +430,7 @@ class TestBalanceComp(unittest.TestCase):
 
         tgt = om.IndepVarComp(name='y_tgt', val=4)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
 
@@ -488,7 +471,7 @@ class TestBalanceComp(unittest.TestCase):
 
         tgt = om.IndepVarComp(name='y_tgt', val=4)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
         model.add_subsystem(name='exec', subsys=exec_comp)
@@ -527,7 +510,7 @@ class TestBalanceComp(unittest.TestCase):
         ivc.add_output(name='y_tgt', val=4)
         ivc.add_output(name='guess_x', val=2.5)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         model.add_subsystem(name='ivc', subsys=ivc, promotes_outputs=['y_tgt', 'guess_x'])
         model.add_subsystem(name='exec', subsys=exec_comp)
@@ -641,7 +624,7 @@ class TestBalanceComp(unittest.TestCase):
 
         bal = om.BalanceComp('x', rhs_val=4.0)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         prob.model.add_subsystem(name='exec', subsys=exec_comp)
 
@@ -680,7 +663,7 @@ class TestBalanceComp(unittest.TestCase):
 
         mult_ivc = om.IndepVarComp(name='mult', val=2.0)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
         prob.model.add_subsystem(name='mult_comp', subsys=mult_ivc, promotes_outputs=['mult'])
@@ -724,7 +707,7 @@ class TestBalanceComp(unittest.TestCase):
 
         mult_ivc = om.IndepVarComp(name='mult', val=2.0)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
         prob.model.add_subsystem(name='mult_comp', subsys=mult_ivc, promotes_outputs=['mult'])
@@ -754,48 +737,14 @@ class TestBalanceComp(unittest.TestCase):
 
         assert_check_partials(cpd, atol=1e-5, rtol=1e-5)
 
-    def test_feature_scalar(self):
-        from numpy.testing import assert_almost_equal
-        import openmdao.api as om
-
-        prob = om.Problem()
-
-        bal = om.BalanceComp()
-        bal.add_balance('x', use_mult=True)
-
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
-
-        prob.model.add_subsystem(name='exec', subsys=exec_comp)
-        prob.model.add_subsystem(name='balance', subsys=bal)
-
-        prob.model.connect('balance.x', 'exec.x')
-        prob.model.connect('exec.y', 'balance.lhs:x')
-
-        prob.model.linear_solver = om.DirectSolver(assemble_jac=True)
-        prob.model.nonlinear_solver = om.NewtonSolver(solve_subsystems=False, maxiter=100, iprint=0)
-
-        prob.setup()
-
-        prob.set_val('balance.rhs:x', 4)
-        prob.set_val('balance.mult:x', 2.)
-
-        # A reasonable initial guess to find the positive root.
-        prob['balance.x'] = 1.0
-
-        prob.run_model()
-
-        assert_almost_equal(prob.get_val('balance.x'), np.sqrt(2), decimal=7)
-
     def test_feature_scalar_with_default_mult(self):
-        from numpy.testing import assert_almost_equal
-        import openmdao.api as om
 
         prob = om.Problem()
 
         bal = om.BalanceComp()
         bal.add_balance('x', use_mult=True, mult_val=2.0)
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': 1}, y={'value': 1})
+        exec_comp = om.ExecComp('y=x**2', x={'val': 1}, y={'val': 1})
 
         prob.model.add_subsystem(name='exec', subsys=exec_comp)
         prob.model.add_subsystem(name='balance', subsys=bal)
@@ -818,20 +767,16 @@ class TestBalanceComp(unittest.TestCase):
         assert_almost_equal(prob.get_val('balance.x'), np.sqrt(2), decimal=7)
 
     def test_feature_vector(self):
-        import numpy as np
-        from numpy.testing import assert_almost_equal
-
-        import openmdao.api as om
 
         n = 100
 
         prob = om.Problem()
 
         exec_comp = om.ExecComp('y=b*x+c',
-                                b={'value': np.random.uniform(0.01, 100, size=n)},
-                                c={'value': np.random.rand(n)},
-                                x={'value': np.zeros(n)},
-                                y={'value': np.ones(n)})
+                                b={'val': np.random.uniform(0.01, 100, size=n)},
+                                c={'val': np.random.rand(n)},
+                                x={'val': np.zeros(n)},
+                                y={'val': np.ones(n)})
 
         prob.model.add_subsystem(name='exec', subsys=exec_comp)
         prob.model.add_subsystem(name='balance', subsys=om.BalanceComp('x', val=np.ones(n)))
@@ -867,7 +812,7 @@ class TestBalanceComp(unittest.TestCase):
 
         mult_ivc = om.IndepVarComp(name='mult', val=2.0*np.ones(shape))
 
-        exec_comp = om.ExecComp('y=x**2', x={'value': np.ones(shape)}, y={'value': np.ones(shape)})
+        exec_comp = om.ExecComp('y=x**2', x={'val': np.ones(shape)}, y={'val': np.ones(shape)})
 
         prob.model.add_subsystem(name='target', subsys=tgt, promotes_outputs=['y_tgt'])
         prob.model.add_subsystem(name='mult_comp', subsys=mult_ivc, promotes_outputs=['mult'])
