@@ -1,5 +1,6 @@
 """ Testing for group finite differencing."""
 import itertools
+import time
 import unittest
 
 try:
@@ -14,6 +15,7 @@ from openmdao.test_suite.components.impl_comp_array import TestImplCompArray, Te
 from openmdao.test_suite.components.paraboloid import Paraboloid
 from openmdao.test_suite.components.sellar import SellarDis1withDerivatives, \
     SellarDis2withDerivatives, SellarDis1CS, SellarDis2CS
+from openmdao.test_suite.components.sellar_feature import SellarNoDerivativesCS
 from openmdao.test_suite.components.simple_comps import DoubleArrayComp
 from openmdao.test_suite.components.unit_conv import SrcComp, TgtCompC, TgtCompF, TgtCompK
 from openmdao.test_suite.groups.parallel_groups import FanInSubbedIDVC
@@ -21,7 +23,7 @@ from openmdao.test_suite.parametric_suite import parametric_suite
 from openmdao.utils.assert_utils import assert_near_equal, assert_warnings
 from openmdao.utils.general_utils import set_pyoptsparse_opt
 from openmdao.utils.mpi import MPI
-import time
+from openmdao.utils.testing_utils import use_tempdirs
 
 try:
     from openmdao.parallel_api import PETScVector
@@ -38,6 +40,7 @@ if OPTIMIZER:
     from openmdao.drivers.pyoptsparse_driver import pyOptSparseDriver
 
 
+@use_tempdirs
 class TestGroupFiniteDifference(unittest.TestCase):
 
     def test_paraboloid(self):
@@ -62,7 +65,7 @@ class TestGroupFiniteDifference(unittest.TestCase):
         assert_near_equal(derivs['f_xy', 'y'], [[8.0]], 1e-6)
 
         # 1 output x 2 inputs
-        self.assertEqual(len(model._approx_schemes['fd']._wrt_meta), 2)
+        self.assertEqual(np.sum(v.size for v in derivs.values()), 2)
 
     def test_fd_count(self):
         # Make sure we aren't doing extra FD steps.
@@ -576,7 +579,7 @@ class TestGroupFiniteDifference(unittest.TestCase):
     def test_full_model_fd(self):
 
         class DontCall(om.LinearRunOnce):
-            def solve(self, vec_names, mode, rel_systems=None):
+            def solve(self, mode, rel_systems=None):
                 raise RuntimeError("This solver should be ignored!")
 
         class Simple(om.ExplicitComponent):
@@ -723,7 +726,7 @@ class TestGroupFiniteDifference(unittest.TestCase):
         p.model.add_constraint('y', equals=0, indices=[0,])
         p.model.add_objective('circle.area', ref=-1)
 
-        p.setup(derivatives=True)
+        p.setup(derivatives=True, force_alloc_complex=True)
 
         p.run_model()
         # Formerly a KeyError
@@ -994,7 +997,7 @@ class TestGroupComplexStep(unittest.TestCase):
         assert_near_equal(derivs['f_xy', 'y'], [[8.0]], 1e-6)
 
         # 1 output x 2 inputs
-        self.assertEqual(len(model._approx_schemes['cs']._wrt_meta), 2)
+        self.assertEqual(np.sum(v.size for v in derivs.values()), 2)
 
     @parameterized.expand(itertools.product([om.DefaultVector, PETScVector]),
                           name_func=lambda f, n, p:
@@ -1962,7 +1965,6 @@ class TestComponentComplexStep(unittest.TestCase):
             self.assertLess(val, 1e-8, msg="Check if CS cleans up after itself.")
 
     def test_stepsizes_under_complex_step(self):
-        import openmdao.api as om
 
         class SimpleComp(om.ExplicitComponent):
 
@@ -1970,7 +1972,9 @@ class TestComponentComplexStep(unittest.TestCase):
                 self.add_input('x', val=1.0)
                 self.add_output('y', val=1.0)
 
-                self.declare_partials(of='y', wrt='x', method='cs')
+                # Need to set step to something other than default because
+                #   OpenMDAO now checks to make sure step is different for compute and check
+                self.declare_partials(of='y', wrt='x', method='cs', step=1e-20)
                 self.count = 0
 
             def compute(self, inputs, outputs):
@@ -1979,7 +1983,7 @@ class TestComponentComplexStep(unittest.TestCase):
                 if self.under_complex_step:
 
                     # Local cs
-                    if self.count == 0 and inputs['x'].imag != 1.0e-40:
+                    if self.count == 0 and inputs['x'].imag != 1.0e-20:
                         msg = "Wrong stepsize for local CS"
                         raise RuntimeError(msg)
 
@@ -1994,7 +1998,7 @@ class TestComponentComplexStep(unittest.TestCase):
                         raise RuntimeError(msg)
 
                     # Check partials cs with default setting forward.
-                    if self.count == 4 and inputs['x'].imag != 1.0e-40:
+                    if self.count == 4 and inputs['x'].imag != 1.0e-20:
                         msg = "Wrong stepsize for check partial default CS forward"
                         raise RuntimeError(msg)
 
@@ -2004,7 +2008,7 @@ class TestComponentComplexStep(unittest.TestCase):
                         raise RuntimeError(msg)
 
                     # Check partials cs with user setting forward.
-                    if self.count == 6 and inputs['x'].imag != 1.0e-40:
+                    if self.count == 6 and inputs['x'].imag != 1.0e-20:
                         msg = "Wrong stepsize for check partial user CS forward"
                         raise RuntimeError(msg)
 
@@ -2038,37 +2042,6 @@ class TestComponentComplexStep(unittest.TestCase):
 
         prob.check_partials(method='cs', step=1e-14, out_stream=None)
 
-    def test_feature_under_complex_step(self):
-        import openmdao.api as om
-
-        class SimpleComp(om.ExplicitComponent):
-
-            def setup(self):
-                self.add_input('x', val=1.0)
-                self.add_output('y', val=1.0)
-
-                self.declare_partials(of='y', wrt='x', method='cs')
-
-            def compute(self, inputs, outputs):
-                outputs['y'] = 3.0*inputs['x']
-
-                if self.under_complex_step:
-                    print("Under complex step")
-                    print("x", inputs['x'])
-                    print("y", outputs['y'])
-
-        prob = om.Problem()
-        prob.model.add_subsystem('comp', SimpleComp())
-
-        prob.model.add_design_var('comp.x', lower=-100, upper=100)
-        prob.model.add_objective('comp.y')
-
-        prob.setup(force_alloc_complex=True)
-
-        prob.run_model()
-
-        prob.compute_totals(of=['comp.y'], wrt=['comp.x'])
-
     def test_partials_bad_sparse_explicit(self):
         class BadSparsityComp(om.ExplicitComponent):
 
@@ -2130,9 +2103,6 @@ class TestComponentComplexStep(unittest.TestCase):
 class ApproxTotalsFeature(unittest.TestCase):
 
     def test_basic(self):
-        import numpy as np
-
-        import openmdao.api as om
 
         class CompOne(om.ExplicitComponent):
 
@@ -2180,9 +2150,6 @@ class ApproxTotalsFeature(unittest.TestCase):
         self.assertEqual(comp2._exec_count, 2)
 
     def test_basic_cs(self):
-        import numpy as np
-
-        import openmdao.api as om
 
         class CompOne(om.ExplicitComponent):
 
@@ -2228,9 +2195,6 @@ class ApproxTotalsFeature(unittest.TestCase):
         assert_near_equal(derivs['z', 'x'], [[300.0]], 1e-6)
 
     def test_arguments(self):
-        import numpy as np
-
-        import openmdao.api as om
 
         class CompOne(om.ExplicitComponent):
 
@@ -2275,8 +2239,6 @@ class ApproxTotalsFeature(unittest.TestCase):
 
     def test_sellarCS(self):
         # Just tests Newton on Sellar with FD derivs.
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar_feature import SellarNoDerivativesCS
 
         prob = om.Problem()
         prob.model = SellarNoDerivativesCS()
@@ -2363,9 +2325,9 @@ class CheckTotalsParallelGroup(unittest.TestCase):
         pg.add_subsystem('dc2', PassThruComp(size=size, time=0.0))
         pg.add_subsystem('dc3', PassThruComp(size=size, time=0.0))
         model.connect('iv.x', ['dc1.x', 'dc2.x', 'dc3.x'])
-        model.add_subsystem('adder', om.ExecComp('z = sum(y1)+sum(y2)+sum(y3)', y1={'value': np.zeros((size, ))},
-                                                                                y2={'value': np.zeros((size, ))},
-                                                                                y3={'value': np.zeros((size, ))}))
+        model.add_subsystem('adder', om.ExecComp('z = sum(y1)+sum(y2)+sum(y3)', y1={'val': np.zeros((size, ))},
+                                                                                y2={'val': np.zeros((size, ))},
+                                                                                y3={'val': np.zeros((size, ))}))
         model.connect('dc1.y', 'adder.y1')
         model.connect('dc2.y', 'adder.y2')
         model.connect('dc3.y', 'adder.y3')
