@@ -358,9 +358,9 @@ class TestShapes(unittest.TestCase):
         p.model.add_subsystem('indep', om.IndepVarComp('x', val=np.arange(10)))
         p.model.add_subsystem('C1',
                               om.ExecComp('y=dot(x, A)',
-                                          x={'value': np.zeros((1, 10))},
-                                          A={'value': np.eye(10)},
-                                          y={'value': np.zeros((1, 10))}))
+                                          x={'val': np.zeros((1, 10))},
+                                          A={'val': np.eye(10)},
+                                          y={'val': np.zeros((1, 10))}))
         p.model.connect('indep.x', 'C1.x')
         p.setup()
         p.run_model()
@@ -371,9 +371,9 @@ class TestShapes(unittest.TestCase):
         p.model.add_subsystem('indep', om.IndepVarComp('x', val=np.arange(10)))
         p.model.add_subsystem('C1',
                               om.ExecComp('y=dot(A, x)',
-                                          x={'value': np.zeros((10, 1))},
-                                          A={'value': np.eye(10)},
-                                          y={'value': np.zeros((10, 1))}))
+                                          x={'val': np.zeros((10, 1))},
+                                          A={'val': np.eye(10)},
+                                          y={'val': np.zeros((10, 1))}))
         p.model.connect('indep.x', 'C1.x')
         p.setup()
         p.run_model()
@@ -383,8 +383,8 @@ class TestShapes(unittest.TestCase):
         p = om.Problem()
         p.model.add_subsystem('indep', om.IndepVarComp('x', val=np.arange(10)[np.newaxis, :]))
         p.model.add_subsystem('C1', om.ExecComp('y=5*x',
-                                                x={'value': np.zeros(10)},
-                                                y={'value': np.zeros(10)}))
+                                                x={'val': np.zeros(10)},
+                                                y={'val': np.zeros(10)}))
         p.model.connect('indep.x', 'C1.x')
         p.setup()
         p.run_model()
@@ -394,8 +394,8 @@ class TestShapes(unittest.TestCase):
         p = om.Problem()
         p.model.add_subsystem('indep', om.IndepVarComp('x', val=np.arange(10)[:, np.newaxis]))
         p.model.add_subsystem('C1', om.ExecComp('y=5*x',
-                                                x={'value': np.zeros(10)},
-                                                y={'value': np.zeros(10)}))
+                                                x={'val': np.zeros(10)},
+                                                y={'val': np.zeros(10)}))
         p.model.connect('indep.x', 'C1.x')
         p.setup()
         p.run_model()
@@ -405,8 +405,8 @@ class TestShapes(unittest.TestCase):
         p = om.Problem()
         p.model.add_subsystem('indep', om.IndepVarComp('x', val=np.arange(10)))
         p.model.add_subsystem('C1', om.ExecComp('y=5*x',
-                                                x={'value': np.zeros((1, 10, 1))},
-                                                y={'value': np.zeros((1, 10, 1))}))
+                                                x={'val': np.zeros((1, 10, 1))},
+                                                y={'val': np.zeros((1, 10, 1))}))
         p.model.connect('indep.x', 'C1.x')
         p.setup()
         p.run_model()
@@ -418,8 +418,8 @@ class TestShapes(unittest.TestCase):
                                                        val=np.arange(10)[np.newaxis, :, np.newaxis,
                                                                          np.newaxis]))
         p.model.add_subsystem('C1', om.ExecComp('y=5*x',
-                                                x={'value': np.zeros((1, 1, 1, 10))},
-                                                y={'value': np.zeros((1, 1, 1, 10))}))
+                                                x={'val': np.zeros((1, 1, 1, 10))},
+                                                y={'val': np.zeros((1, 1, 1, 10))}))
         p.model.connect('indep.x', 'C1.x')
         p.setup()
         p.run_model()
@@ -431,8 +431,8 @@ class TestShapes(unittest.TestCase):
         p.model.add_subsystem('indep', om.IndepVarComp('x', val=np.arange(10)[np.newaxis, :,
                                                                               np.newaxis, np.newaxis]))
         p.model.add_subsystem('C1', om.ExecComp('y=5*x',
-                                                x={'value': np.zeros((5, 2))},
-                                                y={'value': np.zeros((5, 2))}))
+                                                x={'val': np.zeros((5, 2))},
+                                                y={'val': np.zeros((5, 2))}))
         p.model.connect('indep.x', 'C1.x')
 
         expected = "<model> <class Group>: The source and target shapes do not match or are " + \
@@ -557,9 +557,6 @@ class TestConnectionsDistrib(unittest.TestCase):
         # A bug formerly prevented this.
         class TestComp(om.ExplicitComponent):
 
-            def initialize(self):
-                self.options['distributed'] = False
-
             def setup(self):
                 self.add_input('x', shape=2, src_indices=[1, 2], val=-2038.0)
                 self.add_output('y', shape=1)
@@ -592,9 +589,6 @@ class TestConnectionsDistrib(unittest.TestCase):
         # Make sure the flat branch works too.
         class TestComp(om.ExplicitComponent):
 
-            def initialize(self):
-                self.options['distributed'] = False
-
             def setup(self):
                 self.add_input('x', shape=2, src_indices=[1, 2], val=-2038.0, flat_src_indices=True)
                 self.add_output('y', shape=1)
@@ -631,20 +625,16 @@ class TestConnectionsError(unittest.TestCase):
     def test_incompatible_src_indices(self):
         class TestCompDist(om.ExplicitComponent):
         # this comp is distributed and forces PETScTransfer
-            def initialize(self):
-                self.options['distributed'] = True
 
             def setup(self):
-                self.add_input('x', shape=2)
-                self.add_output('y', shape=1)
+                self.add_input('x', shape=2, distributed=True)
+                self.add_output('y', shape=1, distributed=True)
                 self.declare_partials('y', 'x', val=1.0)
 
             def compute(self, inputs, outputs):
                 outputs['y'] = np.sum(inputs['x'])
 
         class TestComp(om.ExplicitComponent):
-            def initialize(self):
-                self.options['distributed'] = False
 
             def setup(self):
                 # read SRC_INDICES on each proc
