@@ -11,6 +11,7 @@ from openmdao.test_suite.components.distributed_components import DistribCompDer
 from openmdao.test_suite.components.paraboloid_distributed import DistParab, DistParabFeature, \
     DistParabDeprecated
 from openmdao.utils.mpi import MPI
+from openmdao.utils.name_maps import rel_name2abs_name
 from openmdao.utils.array_utils import evenly_distrib_idxs
 from openmdao.utils.assert_utils import assert_near_equal, assert_check_partials
 
@@ -1425,8 +1426,14 @@ class TestBugs(unittest.TestCase):
         assert_near_equal(totals['solver.func', 'dvs.state']['abs error'][0], 0.0, tolerance=1e-7)
 
 
+def f_out_dist(Id, Is):
+    return Id**2 - 2.0*Id + 4.0 + np.sum(1.5 * Is ** 2)
+
+def f_out_serial(Id, Is):
+    return Is**2 + 3.0*Is - 5.0 + np.sum(1.5 * Id ** 2)
+
+
 class Distrib_Derivs(om.ExplicitComponent):
-    """Simplest example that combines distributed and serial inputs and outputs."""
 
     def setup(self):
 
@@ -1437,30 +1444,25 @@ class Distrib_Derivs(om.ExplicitComponent):
         self.add_output('out_serial', copy_shape='in_serial')
 
     def compute(self, inputs, outputs):
-        comm = self.comm
         Id = inputs['in_dist']
         Is = inputs['in_serial']
 
-        f_Id = Id**2 - 2.0*Id + 4.0
-        f_Is = 1.5 * Is ** 2
+        # Our local distributed output is a function of the local distributed input and
+        # the serial input.
+        outputs['out_dist'] = f_out_dist(Id, Is)
 
-        # Our local distributed output is a function of local distributed input computed above.
-        # It also is a function of the serial input.
-        outputs['out_dist'] = f_Id + np.sum(f_Is)
-
-        g_Id = 1.5 * Id ** 2
-        g_Is = Is**2 + 3.0*Is - 5.0
-
-        if MPI and comm.size > 1:
+        if self.comm.size > 1:
 
             # We need to gather the summed values to compute the total sum over all procs.
-            local_sum = np.array([np.sum(g_Id)])
+            local_sum = np.array([np.sum(1.5 * Id ** 2)])
             total_sum = local_sum.copy()
             self.comm.Allreduce(local_sum, total_sum, op=MPI.SUM)
 
-            outputs['out_serial'] = g_Is + total_sum[0]
+            # so the serial output is a function of the serial input and the full distributed
+            # input.
+            outputs['out_serial'] = Is**2 + 3.0*Is - 5.0 + total_sum[0]
         else:
-            outputs['out_serial'] = g_Is + np.sum(g_Id)
+            outputs['out_serial'] = f_out_serial(Id, Is)
 
 
 class Distrib_Derivs_Matfree(Distrib_Derivs):
@@ -1483,9 +1485,9 @@ class Distrib_Derivs_Matfree(Distrib_Derivs):
             if 'out_serial' in d_outputs:
                 if 'in_dist' in d_inputs:
                     deriv = np.tile(dg_dId, size).reshape((size, local_size)).dot(d_inputs['in_dist'])
-                    cpy = deriv.copy()
-                    self.comm.Allreduce(cpy, deriv, op=MPI.SUM)
-                    d_outputs['out_serial'] += deriv
+                    deriv_sum = np.zeros(deriv.size)
+                    self.comm.Allreduce(deriv, deriv_sum, op=MPI.SUM)
+                    d_outputs['out_serial'] += deriv_sum
                 if 'in_serial' in d_inputs:
                     d_outputs['out_serial'] += (2.0 * Is + 3.0) * d_inputs['in_serial']
         else:  # rev
@@ -1496,7 +1498,7 @@ class Distrib_Derivs_Matfree(Distrib_Derivs):
                     d_inputs['in_serial'] += np.tile(df_dIs, local_size).reshape((local_size, size)).T.dot(d_outputs['out_dist'])
             if 'out_serial' in d_outputs:
                 if 'in_dist' in d_inputs:
-                    full = d_outputs['out_serial'].copy()
+                    full = np.zeros(d_outputs['out_serial'].size)
                     # add up contributions from the serial variable that is duplicated over
                     # all of the procs.
                     self.comm.Allreduce(d_outputs['out_serial'], full, op=MPI.SUM)
@@ -1506,7 +1508,6 @@ class Distrib_Derivs_Matfree(Distrib_Derivs):
 
 
 class Distrib_DerivsFD(Distrib_Derivs):
-    """Simplest example that combines distributed and serial inputs and outputs."""
 
     def setup_partials(self):
         self.declare_partials('*', '*', method='fd')
@@ -1520,13 +1521,94 @@ class Distrib_DerivsErr(Distrib_Derivs):
     def compute_partials(self, inputs, partials):
         pass  # do nothing here.  Error will occur before calling this.
 
+# this is similar to Distrib_Derivs except we add in the product of inputs rather than the
+# summation of inputs.
+class Distrib_Derivs_Prod(om.ExplicitComponent):
+
+    def setup(self):
+
+        self.add_input('in_dist', shape_by_conn=True, distributed=True)
+        self.add_input('in_serial', shape_by_conn=True)
+
+        self.add_output('out_dist', copy_shape='in_dist', distributed=True)
+        self.add_output('out_serial', copy_shape='in_serial')
+
+    def compute(self, inputs, outputs):
+        Id = inputs['in_dist']
+        Is = inputs['in_serial']
+
+        # Our local distributed output is a function of local distributed input and the
+        # serial input.
+        outputs['out_dist'] = Id**2 - 2.0*Id + 4.0 + np.prod(1.5 * Is ** 2)
+
+        if self.comm.size > 1:
+            # We need to gather the multplied values to compute the total product over all procs.
+            local_prod = np.array([np.prod(1.5 * Id ** 2)])
+            total_prod = local_prod.copy()
+            self.comm.Allreduce(local_prod, total_prod, op=MPI.PROD)
+
+        outputs['out_serial'] = Is**2 + 3.0*Is - 5.0 + total_prod
+
+
+class Distrib_Derivs_Prod_Matfree(Distrib_Derivs_Prod):
+    def compute_jacvec_product(self, inputs, d_inputs, d_outputs, mode):
+        Id = inputs['in_dist']
+        Is = inputs['in_serial']
+
+        size = len(Is)
+        local_size = len(Id)
+
+        idx = self._var_allprocs_abs2idx[rel_name2abs_name(self, 'in_dist')]
+        sizes = self._var_sizes['input'][:, idx]
+        start = np.sum(sizes[:self.comm.rank])
+        end = start + sizes[self.comm.rank]
+
+        d_dIs = np.zeros((local_size, size))
+        for i in range(size):
+            d_dIs[:, i] = 3.*Is[i]*np.prod([1.5*Is[j]**2 for j in range(size) if i != j])
+
+        # unfortunately we need the full distributed input here in order to compute the d_dId
+        # matrix.
+        Idfull = np.hstack(self.comm.allgather(Id))
+        d_dId = np.zeros((size, local_size))
+        for i in range(start, end):
+            d_dId[:, i-start] = 3.*Idfull[i]*np.prod([1.5*Idfull[j]**2 for j in range(size) if i != j])
+
+        if mode == 'fwd':
+            if 'out_dist' in d_outputs:
+                if 'in_dist' in d_inputs:
+                    d_outputs['out_dist'] += (2.0 * Id - 2.0) * d_inputs['in_dist']
+                if 'in_serial' in d_inputs:
+                    d_outputs['out_dist'] += d_dIs.dot(d_inputs['in_serial'])
+            if 'out_serial' in d_outputs:
+                if 'in_dist' in d_inputs:
+                    deriv = d_dId.dot(d_inputs['in_dist'])
+                    deriv_sum = np.zeros(deriv.size)
+                    self.comm.Allreduce(deriv, deriv_sum, op=MPI.SUM)
+                    d_outputs['out_serial'] += deriv_sum
+                if 'in_serial' in d_inputs:
+                    d_outputs['out_serial'] += (2.0 * Is + 3.0) * d_inputs['in_serial']
+        else:  # rev
+            if 'out_dist' in d_outputs:
+                if 'in_dist' in d_inputs:
+                    d_inputs['in_dist'] += (2.0 * Id - 2.0) * d_outputs['out_dist']
+                if 'in_serial' in d_inputs:
+                    d_inputs['in_serial'] += d_dIs.T.dot(d_outputs['out_dist'])
+            if 'out_serial' in d_outputs:
+                if 'in_dist' in d_inputs:
+                    full = np.zeros(d_outputs['out_serial'].size)
+                    self.comm.Allreduce(d_outputs['out_serial'], full, op=MPI.SUM)
+                    d_inputs['in_dist'] += d_dId.T.dot(full)
+                if 'in_serial' in d_inputs:
+                    d_inputs['in_serial'] += (2.0 * Is + 3.0) * d_outputs['out_serial']
+
 
 @unittest.skipUnless(MPI and PETScVector, "MPI and PETSc are required.")
 class TestDistribBugs(unittest.TestCase):
 
     N_PROCS = 2
 
-    def get_problem(self, comp_class, mode='auto', stacked=True):
+    def get_problem(self, comp_class, mode='auto', stacked=False):
         size = 5
 
         if MPI:
@@ -1535,8 +1617,7 @@ class TestDistribBugs(unittest.TestCase):
             sizes, offsets = evenly_distrib_idxs(comm.size, size)
         else:
             rank = 0
-            sizes = {rank : size}
-            offsets = {rank : 0}
+            sizes, offsets = [size], [0]
 
         model = om.Group()
 
@@ -1560,8 +1641,8 @@ class TestDistribBugs(unittest.TestCase):
         prob = om.Problem(model)
         prob.setup(mode=mode, force_alloc_complex=True)
 
-        self.x_dist_init = x_dist_init = 3.0 + np.arange(size)[offsets[rank]:offsets[rank] + sizes[rank]]
-        self.x_serial_init = x_serial_init = 1.0 + 2.0*np.arange(size)
+        self.x_dist_init = x_dist_init = (3.0 + np.arange(size)[offsets[rank]:offsets[rank] + sizes[rank]]) * .1
+        self.x_serial_init = x_serial_init = (1.0 + 2.0*np.arange(size)) * .1
 
         # This set operates on the entire vector.
         prob.set_val('indep.x_dist', x_dist_init)
@@ -1571,54 +1652,110 @@ class TestDistribBugs(unittest.TestCase):
 
         return prob
 
+    def _compare_totals(self, totals):
+        fails = []
+        for key, val in totals.items():
+            try:
+                analytic = val['J_fwd']
+                fd = val['J_fd']
+            except Exception as err:
+                self.fail(f"For key {key}: {err}")
+            try:
+                assert_near_equal(val['rel error'][0], 0.0, 1e-6)
+            except ValueError as err:
+                fails.append((key, val, err))
+        if fails:
+            msg = '\n\n'.join([f"Totals differ for {key}:\nAnalytic:\n{val['J_fwd']}\nFD:\n{val['J_fd']}\n{err}" for key, val, err in fails])
+            self.fail(msg)
+
     def test_get_val(self):
         prob = self.get_problem(Distrib_Derivs_Matfree, stacked=False)
+        indep = prob.model.indep
+        full_dist_init = np.hstack(indep.comm.allgather(indep._outputs['x_dist'].flat[:]))
+        D1_out_dist_full = f_out_dist(full_dist_init, self.x_serial_init)
         if prob.model.comm.rank == 0:
-            D1_out_dist = np.array([254.5, 259.5, 266.5])
+            D1_out_dist = f_out_dist(self.x_dist_init, self.x_serial_init)
         else:
-            D1_out_dist = np.array([275.5, 286.5])
+            D1_out_dist = f_out_dist(self.x_dist_init, self.x_serial_init)
 
-        D1_out_dist_full = np.array([254.5, 259.5, 266.5, 275.5, 286.5])
-        D1_out_serial = np.array([201.5, 215.5, 237.5, 267.5, 305.5])
+        D1_out_serial = f_out_serial(full_dist_init, self.x_serial_init)
 
         vnames = ['indep.x_dist', 'indep.x_serial', 'D1.out_dist', 'D1.out_serial']
         expected = [self.x_dist_init, self.x_serial_init, D1_out_dist, D1_out_serial]
-        expected_remote = [3+np.arange(5), self.x_serial_init, D1_out_dist_full, D1_out_serial]
+        expected_remote = [full_dist_init, self.x_serial_init, D1_out_dist_full, D1_out_serial]
         for var, ex, ex_remote in zip(vnames, expected, expected_remote):
             val = prob.get_val(var)
-            assert_near_equal(val, ex, tolerance=1e-8)
             full_val = prob.get_val(var, get_remote=True)
+            assert_near_equal(val, ex, tolerance=1e-8)
             assert_near_equal(full_val, ex_remote, tolerance=1e-8)
 
     def test_check_totals_fwd(self):
         prob = self.get_problem(Distrib_Derivs_Matfree, mode='fwd')
-        totals = prob.check_totals(method='cs', out_stream=None, of=['D2.out_serial', 'D2.out_dist'],
+        totals = prob.check_totals(method='cs', out_stream=None, of=['D1.out_serial', 'D1.out_dist'],
                                         wrt=['indep.x_serial', 'indep.x_dist'])
-        for key, val in totals.items():
-            try:
-                assert_near_equal(val['rel error'][0], 0.0, 1e-6)
-            except Exception as err:
-                self.fail(f"For key {key}: {err}")
+        self._compare_totals(totals)
+
+    def test_check_totals_prod_fwd(self):
+        prob = self.get_problem(Distrib_Derivs_Prod_Matfree, mode='fwd')
+        totals = prob.check_totals(method='cs', out_stream=None, of=['D1.out_serial', 'D1.out_dist'],
+                                        wrt=['indep.x_serial', 'indep.x_dist'])
+        self._compare_totals(totals)
 
     def test_check_totals_rev(self):
         prob = self.get_problem(Distrib_Derivs_Matfree, mode='rev')
+        totals = prob.check_totals(method='cs', out_stream=None, of=['D1.out_serial', 'D1.out_dist'],
+                                                   wrt=['indep.x_serial', 'indep.x_dist'])
+        self._compare_totals(totals)
+
+    def test_check_totals_prod_rev(self):
+        prob = self.get_problem(Distrib_Derivs_Prod_Matfree, mode='rev')
+        totals = prob.check_totals(method='cs', out_stream=None, of=['D1.out_serial', 'D1.out_dist'],
+                                                   wrt=['indep.x_serial', 'indep.x_dist'])
+        self._compare_totals(totals)
+
+    def test_check_totals_fwd_stacked(self):
+        prob = self.get_problem(Distrib_Derivs_Matfree, mode='fwd', stacked=True)
+        totals = prob.check_totals(method='cs', out_stream=None, of=['D2.out_serial', 'D2.out_dist'],
+                                        wrt=['indep.x_serial', 'indep.x_dist'])
+        self._compare_totals(totals)
+
+    def test_check_totals_prod_fwd_stacked(self):
+        prob = self.get_problem(Distrib_Derivs_Prod_Matfree, mode='fwd', stacked=True)
+        totals = prob.check_totals(method='cs', out_stream=None, of=['D2.out_serial', 'D2.out_dist'],
+                                        wrt=['indep.x_serial', 'indep.x_dist'])
+        self._compare_totals(totals)
+
+    def test_check_totals_rev_stacked(self):
+        prob = self.get_problem(Distrib_Derivs_Matfree, mode='rev', stacked=True)
         totals = prob.check_totals(method='cs', out_stream=None, of=['D2.out_serial', 'D2.out_dist'],
                                                    wrt=['indep.x_serial', 'indep.x_dist'])
-        for key, val in totals.items():
-            try:
-                assert_near_equal(val['rel error'][0], 0.0, 1e-6)
-            except Exception as err:
-                self.fail(f"For key {key}: {err}")
+        self._compare_totals(totals)
+
+    def test_check_totals_prod_rev_stacked(self):
+        prob = self.get_problem(Distrib_Derivs_Prod_Matfree, mode='rev', stacked=True)
+        totals = prob.check_totals(method='cs', out_stream=None, of=['D2.out_serial', 'D2.out_dist'],
+                                                   wrt=['indep.x_serial', 'indep.x_dist'])
+        self._compare_totals(totals)
 
     def test_check_partials_cs(self):
         prob = self.get_problem(Distrib_Derivs_Matfree)
         data = prob.check_partials(method='cs', show_only_incorrect=True)
-        assert_check_partials(data, atol=1e-10)
+        assert_check_partials(data)
+
+    def test_check_partials_prod_cs(self):
+        prob = self.get_problem(Distrib_Derivs_Prod_Matfree)
+        data = prob.check_partials(method='cs', show_only_incorrect=True)
+        assert_check_partials(data)
 
     def test_check_partials_fd(self):
         prob = self.get_problem(Distrib_Derivs_Matfree)
         data = prob.check_partials(method='fd', show_only_incorrect=True)
-        assert_check_partials(data, atol=1e-3)
+        assert_check_partials(data, atol=6e-6, rtol=1.5e-6)
+
+    def test_check_partials_prod_fd(self):
+        prob = self.get_problem(Distrib_Derivs_Prod_Matfree)
+        data = prob.check_partials(method='fd', show_only_incorrect=True)
+        assert_check_partials(data, rtol=5e-6, atol=3e-6)
 
     def test_check_err(self):
         with self.assertRaises(RuntimeError) as cm:
