@@ -6,6 +6,7 @@ import openmdao.api as om
 import openmdao.utils.coloring as coloring_mod
 from openmdao.utils.assert_utils import assert_near_equal
 from openmdao.utils.general_utils import set_pyoptsparse_opt
+from openmdao.utils.testing_utils import use_tempdirs
 
 
 # check that pyoptsparse is installed
@@ -470,6 +471,7 @@ def make_traj():
     return traj
 
 
+@use_tempdirs
 @unittest.skipUnless(OPTIMIZER, "This test requires pyOptSparseDriver.")
 class TestMPIColoringBug(unittest.TestCase):
     N_PROCS = 2
@@ -497,7 +499,7 @@ class TestMPIColoringBug(unittest.TestCase):
         p.setup(mode='rev')
 
         # Set Initial Guesses
-        p.set_val('design_parameters:c', value=1.5)
+        p.set_val('design_parameters:c', val=1.5)
 
         of = ['phases.burn2.indep_states.states:deltav', 'phases.burn1.collocation_constraint.defects:deltav', 'phases.burn2.collocation_constraint.defects:deltav', ]
         wrt = ['phases.burn1.indep_states.states:deltav', 'phases.burn2.indep_states.states:deltav']
