@@ -1,7 +1,6 @@
 """ Unit tests for the Pyoptsparse Driver."""
 
 import copy
-import sys
 import unittest
 
 from distutils.version import LooseVersion
@@ -17,7 +16,7 @@ from openmdao.utils.assert_utils import assert_near_equal, assert_warning
 from openmdao.utils.general_utils import set_pyoptsparse_opt, run_driver
 from openmdao.utils.testing_utils import use_tempdirs, require_pyoptsparse
 from openmdao.utils.mpi import MPI
-from openmdao.warnings import OMDeprecationWarning
+from openmdao.utils.om_warnings import OMDeprecationWarning
 
 # check that pyoptsparse is installed
 # if it is, try to use SNOPT but fall back to SLSQP
@@ -2286,10 +2285,6 @@ class TestPyoptSparseFeature(unittest.TestCase):
             raise unittest.SkipTest("pyoptsparse is not installed")
 
     def test_basic(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
 
         prob = om.Problem()
         model = prob.model = SellarDerivativesGrouped()
@@ -2311,10 +2306,6 @@ class TestPyoptSparseFeature(unittest.TestCase):
         assert_near_equal(prob.get_val('z', indices=0), 1.9776, 1e-3)
 
     def test_settings_print(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
 
         prob = om.Problem()
         model = prob.model = SellarDerivativesGrouped()
@@ -2337,10 +2328,6 @@ class TestPyoptSparseFeature(unittest.TestCase):
         assert_near_equal(prob.get_val('z', indices=0), 1.9776, 1e-3)
 
     def test_slsqp_atol(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
 
         prob = om.Problem()
         model = prob.model = SellarDerivativesGrouped()
@@ -2364,10 +2351,6 @@ class TestPyoptSparseFeature(unittest.TestCase):
         assert_near_equal(prob.get_val('z', indices=0), 1.9776, 1e-3)
 
     def test_slsqp_maxit(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
 
         prob = om.Problem()
         model = prob.model = SellarDerivativesGrouped()
@@ -2392,18 +2375,12 @@ class TestPyoptSparseFeature(unittest.TestCase):
 
 
 class TestPyoptSparseSnoptFeature(unittest.TestCase):
-    # all of these tests require SNOPT
+    # All of these tests require SNOPT
 
     def setUp(self):
-        from openmdao.utils.general_utils import set_pyoptsparse_opt
-
         OPT, OPTIMIZER = set_pyoptsparse_opt('SNOPT', fallback=False)
 
     def test_snopt_atol(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
 
         prob = om.Problem()
         model = prob.model = SellarDerivativesGrouped()
@@ -2427,10 +2404,6 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
         assert_near_equal(prob.get_val('z', indices=0), 1.9776, 1e-3)
 
     def test_snopt_maxit(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivativesGrouped
 
         prob = om.Problem()
         model = prob.model = SellarDerivativesGrouped()
@@ -2657,7 +2630,6 @@ class TestPyoptSparseSnoptFeature(unittest.TestCase):
         self.assertEqual(output[-2], ('NL: NLBGS Converged'))
 
     def test_signal_set(self):
-        import openmdao.api as om
         import signal
 
         prob = om.Problem()
