@@ -220,14 +220,14 @@ class AssembledJacobian(Jacobian):
         conns = {} if isinstance(system, Component) else system._conn_global_abs_in2out
 
         iproc = system.comm.rank
-        sizes = system._var_sizes['linear']['input']
-        abs2idx = system._var_allprocs_abs2idx['linear']
+        sizes = system._var_sizes['input']
+        abs2idx = system._var_allprocs_abs2idx
         in_offset = {n: np.sum(sizes[iproc, :abs2idx[n]]) for n in
                      system._var_abs2meta['input'] if n not in conns}
 
         subjacs_info = self._subjacs_info
 
-        sizes = system._var_sizes['linear']['output']
+        sizes = system._var_sizes['output']
         for s in system.system_iter(recurse=True, include_self=True, typ=Component):
             for res_abs_name, res_meta in s._var_abs2meta['output'].items():
                 res_offset = np.sum(sizes[iproc, :abs2idx[res_abs_name]])
@@ -340,17 +340,17 @@ class AssembledJacobian(Jacobian):
 
         if self._randomize:
             for key in iters:
-                int_mtx._update_submat(key, self._randomize_subjac(subjacs[key]['value'], key))
+                int_mtx._update_submat(key, self._randomize_subjac(subjacs[key]['val'], key))
 
             for key in iters_in_ext:
-                ext_mtx._update_submat(key, self._randomize_subjac(subjacs[key]['value'], key))
+                ext_mtx._update_submat(key, self._randomize_subjac(subjacs[key]['val'], key))
         else:
 
             for key in iters:
-                int_mtx._update_submat(key, subjacs[key]['value'])
+                int_mtx._update_submat(key, subjacs[key]['val'])
 
             for key in iters_in_ext:
-                ext_mtx._update_submat(key, subjacs[key]['value'])
+                ext_mtx._update_submat(key, subjacs[key]['val'])
 
         int_mtx._post_update()
 
