@@ -433,10 +433,10 @@ class Case(object):
             User defined tags that can be used to filter what gets listed. Only inputs with the
             given tags will be listed.
             Default is None, which means there will be no filtering based on tags.
-        includes : iter of str or None
+        includes : str, iter of str, or None
             Glob patterns for pathnames to include in the check. Default is None, which
             includes all.
-        excludes : iter of str or None
+        excludes : str, iter of str, or None
             Glob patterns for pathnames to exclude from the check. Default is None, which
             excludes nothing.
         out_stream : file-like object
@@ -461,6 +461,12 @@ class Case(object):
         else:
             values = val
 
+        if isinstance(includes, str):
+            includes = [includes, ]
+
+        if isinstance(excludes, str):
+            excludes = [excludes, ]
+
         if self.inputs is not None:
             for var_name in self.inputs.absolute_names():
                 # Filter based on tags
@@ -560,10 +566,10 @@ class Case(object):
             User defined tags that can be used to filter what gets listed. Only outputs with the
             given tags will be listed.
             Default is None, which means there will be no filtering based on tags.
-        includes : iter of str or None
+        includes : str, iter of str, or None
             Glob patterns for pathnames to include in the check. Default is None, which
             includes all.
-        excludes : iter of str or None
+        excludes : str, iter of str, or None
             Glob patterns for pathnames to exclude from the check. Default is None, which
             excludes nothing.
         list_autoivcs : bool
@@ -591,6 +597,12 @@ class Case(object):
         else:
             values = val
 
+        if isinstance(includes, str):
+            includes = [includes, ]
+
+        if isinstance(excludes, str):
+            excludes = [excludes, ]
+
         for var_name in self.outputs.absolute_names():
             if not list_autoivcs and var_name.startswith('_auto_ivc.'):
                 continue
