@@ -10,6 +10,7 @@ import numpy as np
 
 import openmdao.api as om
 from openmdao.test_suite.components.double_sellar import SubSellar
+from openmdao.test_suite.components.sellar import SellarDerivatives
 
 from openmdao.utils.general_utils import run_model
 from openmdao.utils.mpi import MPI
@@ -24,8 +25,6 @@ except ImportError:
 class TestSolverPrint(unittest.TestCase):
 
     def test_feature_iprint_neg1(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -38,8 +37,8 @@ class TestSolverPrint(unittest.TestCase):
         newton.options['maxiter'] = 2
 
         # use a real bad initial guess
-        prob['y1'] = 10000
-        prob['y2'] = -26
+        prob.set_val('y1', 10000)
+        prob.set_val('y2', -26)
 
         newton.options['iprint'] = -1
         scipy.options['iprint'] = -1
@@ -58,8 +57,6 @@ class TestSolverPrint(unittest.TestCase):
         self.assertEqual(str_out.getvalue().strip(), "")
 
     def test_feature_iprint_0(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -71,8 +68,8 @@ class TestSolverPrint(unittest.TestCase):
 
         newton.options['maxiter'] = 1
 
-        prob['y1'] = 10000
-        prob['y2'] = -26
+        prob.set_val('y1', 10000)
+        prob.set_val('y2', -26)
 
         newton.options['iprint'] = 0
         scipy.options['iprint'] = 0
@@ -94,8 +91,6 @@ class TestSolverPrint(unittest.TestCase):
                          "1 iterations.")
 
     def test_feature_iprint_1(self, stdout=None):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -107,8 +102,8 @@ class TestSolverPrint(unittest.TestCase):
 
         newton.options['maxiter'] = 20
 
-        prob['y1'] = 10000
-        prob['y2'] = -26
+        prob.set_val('y1', 10000)
+        prob.set_val('y2', -26)
 
         newton.options['iprint'] = 1
         scipy.options['iprint'] = 0
@@ -128,8 +123,6 @@ class TestSolverPrint(unittest.TestCase):
                          "NL: Newton Converged in 2 iterations")
 
     def test_feature_iprint_2(self):
-        import openmdao.api as om
-        from openmdao.test_suite.components.sellar import SellarDerivatives
 
         prob = om.Problem()
         prob.model = SellarDerivatives()
@@ -141,8 +134,8 @@ class TestSolverPrint(unittest.TestCase):
 
         newton.options['maxiter'] = 20
 
-        prob['y1'] = 10000
-        prob['y2'] = -20
+        prob.set_val('y1', 10000)
+        prob.set_val('y2', -26)
 
         newton.options['iprint'] = 2
         scipy.options['iprint'] = 1
@@ -271,22 +264,15 @@ class TestSolverPrint(unittest.TestCase):
         self.assertGreaterEqual(output.count('NL: NLBJ'), 2)
 
     def test_feature_set_solver_print1(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.double_sellar import SubSellar
 
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
-
-        sub1 = model.add_subsystem('sub1', om.Group())
-        sub2 = sub1.add_subsystem('sub2', om.Group())
-        g1 = sub2.add_subsystem('g1', SubSellar())
+        sub1 = model.add_subsystem('sub1', om.Group(), promotes_inputs=['z'])
+        sub2 = sub1.add_subsystem('sub2', om.Group(), promotes_inputs=['z'])
+        g1 = sub2.add_subsystem('g1', SubSellar(), promotes_inputs=['z'])
         g2 = model.add_subsystem('g2', SubSellar())
 
-        model.connect('pz.z', 'sub1.sub2.g1.z')
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
@@ -306,6 +292,7 @@ class TestSolverPrint(unittest.TestCase):
         prob.set_solver_print(level=2)
 
         prob.setup()
+        prob.set_val('z', np.array([5.0, 2.0]))
         prob.run_model()
 
     def test_set_solver_print1(self):
@@ -329,22 +316,15 @@ class TestSolverPrint(unittest.TestCase):
 
 
     def test_feature_set_solver_print2(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.double_sellar import SubSellar
 
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
-
-        sub1 = model.add_subsystem('sub1', om.Group())
-        sub2 = sub1.add_subsystem('sub2', om.Group())
-        g1 = sub2.add_subsystem('g1', SubSellar())
+        sub1 = model.add_subsystem('sub1', om.Group(), promotes_inputs=['z'])
+        sub2 = sub1.add_subsystem('sub2', om.Group(), promotes_inputs=['z'])
+        g1 = sub2.add_subsystem('g1', SubSellar(), promotes_inputs=['z'])
         g2 = model.add_subsystem('g2', SubSellar())
 
-        model.connect('pz.z', 'sub1.sub2.g1.z')
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
@@ -365,6 +345,7 @@ class TestSolverPrint(unittest.TestCase):
         prob.set_solver_print(level=-1, type_='LN')
 
         prob.setup()
+        prob.set_val('z', np.array([5.0, 2.0]))
         prob.run_model()
 
     def test_set_solver_print2(self):
@@ -384,22 +365,15 @@ class TestSolverPrint(unittest.TestCase):
         self.assertGreaterEqual(output.count('LS: BCHK'), 2)
 
     def test_feature_set_solver_print3(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.double_sellar import SubSellar
 
         prob = om.Problem()
         model = prob.model
 
-        model.add_subsystem('pz', om.IndepVarComp('z', np.array([5.0, 2.0])))
-
-        sub1 = model.add_subsystem('sub1', om.Group())
-        sub2 = sub1.add_subsystem('sub2', om.Group())
-        g1 = sub2.add_subsystem('g1', SubSellar())
+        sub1 = model.add_subsystem('sub1', om.Group(), promotes_inputs=['z'])
+        sub2 = sub1.add_subsystem('sub2', om.Group(), promotes_inputs=['z'])
+        g1 = sub2.add_subsystem('g1', SubSellar(), promotes_inputs=['z'])
         g2 = model.add_subsystem('g2', SubSellar())
 
-        model.connect('pz.z', 'sub1.sub2.g1.z')
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
@@ -420,6 +394,7 @@ class TestSolverPrint(unittest.TestCase):
         prob.set_solver_print(level=2, depth=2)
 
         prob.setup()
+        prob.set_val('z', np.array([5.0, 2.0]))
         prob.run_model()
 
     def test_set_solver_print3(self):
@@ -441,10 +416,6 @@ class TestSolverPrint(unittest.TestCase):
         self.assertGreaterEqual(output.count('LN: SCIPY'), 2)
 
     def test_feature_set_solver_print4(self):
-        import numpy as np
-
-        import openmdao.api as om
-        from openmdao.test_suite.components.double_sellar import SubSellar
 
         prob = om.Problem()
         model = prob.model
@@ -456,7 +427,6 @@ class TestSolverPrint(unittest.TestCase):
         g1 = sub2.add_subsystem('g1', SubSellar())
         g2 = model.add_subsystem('g2', SubSellar())
 
-        model.connect('pz.z', 'sub1.sub2.g1.z')
         model.connect('sub1.sub2.g1.y2', 'g2.x')
         model.connect('g2.y2', 'sub1.sub2.g1.x')
 
