@@ -33,6 +33,7 @@ class SellarDis1(om.ExplicitComponent):
         # Coupling output
         self.add_output('y1', val=1.0)
 
+    def setup_partials(self):
         # Finite difference all partials.
         self.declare_partials('*', '*', method='fd')
 
@@ -64,6 +65,7 @@ class SellarDis2(om.ExplicitComponent):
         # Coupling output
         self.add_output('y2', val=1.0)
 
+    def setup_partials(self):
         # Finite difference all partials.
         self.declare_partials('*', '*', method='fd')
 
@@ -136,6 +138,7 @@ class SellarMDAWithUnits(om.Group):
             # Coupling output
             self.add_output('y1', val=1.0, units='degC')
 
+        def setup_partials(self):
             # Finite difference all partials.
             self.declare_partials('*', '*', method='fd')
 
@@ -167,6 +170,7 @@ class SellarMDAWithUnits(om.Group):
             # Coupling output
             self.add_output('y2', val=1.0, units='degC')
 
+        def setup_partials(self):
             # Finite difference all partials.
             self.declare_partials('*', '*', method='fd')
 
@@ -203,8 +207,8 @@ class SellarMDAWithUnits(om.Group):
         cycle.nonlinear_solver = om.NonlinearBlockGS()
 
         self.add_subsystem('obj_cmp', om.ExecComp('obj = x**2 + z[1] + y1 + exp(-y2)',
-                                                  z={'value': np.array([0.0, 0.0]), 'units': 'degC'},
-                                                  x={'value': 0.0, 'units': 'degC'},
+                                                  z={'val': np.array([0.0, 0.0]), 'units': 'degC'},
+                                                  x={'val': 0.0, 'units': 'degC'},
                                                   y1={'units': 'degC'},
                                                   y2={'units': 'degC'}),
                            promotes=['x', 'z', 'y1', 'y2', 'obj'])
@@ -264,6 +268,7 @@ class SellarDis1CS(om.ExplicitComponent):
         # Coupling output
         self.add_output('y1', val=1.0)
 
+    def setup_partials(self):
         # Finite difference all partials.
         self.declare_partials('*', '*', method='cs')
 
@@ -296,6 +301,7 @@ class SellarDis2CS(om.ExplicitComponent):
         # Coupling output
         self.add_output('y2', val=1.0)
 
+    def setup_partials(self):
         # Finite difference all partials.
         self.declare_partials('*', '*', method='cs')
 
