@@ -77,73 +77,93 @@ def _convert_ndarray_to_support_nans_in_json(val):
     object : list, possibly nested
         The equivalent list with any nan values replaced with the string "nan".
     """
+    # do a quick check for any nans or infs and if not we can avoid the slow check
+    nans = np.where(np.isnan(val))
+    infs = np.where(np.isinf(val))
+    if nans[0].size == 0 and infs[0].size == 0:
+        return val.tolist()
+
     val_as_list = val.tolist()
     _convert_nans_in_nested_list(val_as_list)
-    return(val_as_list)
+    return val_as_list
 
 
-def _get_var_dict(system, typ, name, is_parallel):
-    if name in system._var_discrete[typ]:
-        meta = system._var_discrete[typ][name]
-        is_discrete = True
-    else:
-        if name in system._var_abs2meta['output']:
-            meta = system._var_abs2meta['output'][name]
-        else:
-            meta = system._var_abs2meta['input'][name]
-        name = system._var_abs2prom[typ][name]
-        is_discrete = False
+def _get_var_dict(system, typ, name, is_parallel, is_implicit):
+    if name in system._var_abs2meta[typ]:
+        meta = system._var_abs2meta[typ][name]
+        prom = system._var_abs2prom[typ][name]
+        val = meta['val']
+        is_dist = MPI is not None and meta['distributed']
 
-    var_dict = {}
+        var_dict = {
+            'name': prom,
+            'type': typ,
+            'dtype': type(val).__name__,
+            'is_discrete': False,
+            'distributed': is_dist,
+            'shape': str(meta['shape']),
+        }
 
-    var_dict['name'] = name
-    var_dict['type'] = typ
-    if typ == 'output':
-        isimplicit = isinstance(system, ImplicitComponent)
-        var_dict['type'] = 'output'
-        var_dict['implicit'] = isimplicit
+        if typ == 'output':
+            var_dict['implicit'] = is_implicit
+            vec = system._outputs
+        else:  # input
+            if MPI:
+                # for inputs if we're under MPI, we only retrieve the value currently stored
+                # in the input vector and not from the connected source because that source
+                # could be remote.
+                vec = system._inputs
+            else:
+                vec = None
+
+        # if 'vec' is not None at this point, we can retrieve the value using vec._abs_get_val,
+        # which is a faster call than system.get_val.
 
-    var_dict['dtype'] = type(meta['val']).__name__
-    if 'units' in meta:
         if meta['units'] is None:
             var_dict['units'] = 'None'
         else:
             var_dict['units'] = meta['units']
 
-    if 'shape' in meta:
-        var_dict['shape'] = str(meta['shape'])
-
-    if 'distributed' in meta:
-        var_dict['distributed'] = is_distributed = meta['distributed']
-    else:
-        is_distributed = False
-
-    if 'surrogate_name' in meta:
-        var_dict['surrogate_name'] = meta['surrogate_name']
-
-    var_dict['is_discrete'] = is_discrete
-
-    if is_discrete:
-        if isinstance(meta['val'], (int, str, list, dict, complex, np.ndarray)) or MPI is None:
-            var_dict['val'] = default_noraise(system.get_val(name))
-        else:
-            var_dict['val'] = type(meta['val']).__name__
-    else:
-        if meta['val'].size < _MAX_ARRAY_SIZE_FOR_REPR_VAL:
+        if val.size < _MAX_ARRAY_SIZE_FOR_REPR_VAL:
             if not MPI:
                 # get the current value
-                var_dict['val'] = _convert_ndarray_to_support_nans_in_json(system.get_val(name))
-            elif is_parallel or is_distributed:
+                if vec:
+                    var_dict['val'] = _convert_ndarray_to_support_nans_in_json(
+                        vec._abs_get_val(name, flat=False))
+                else:
+                    var_dict['val'] = _convert_ndarray_to_support_nans_in_json(
+                        system.get_val(prom))
+            elif is_parallel or is_dist:
                 # we can't access non-local values, so just get the initial value
-                var_dict['val'] = meta['val']
+                var_dict['val'] = val
                 var_dict['initial_value'] = True
             else:
                 # get the current value but don't try to get it from the source,
                 # which could be remote under MPI
-                val = system.get_val(name, from_src=False)
-                var_dict['val'] = _convert_ndarray_to_support_nans_in_json(val)
+                if vec:
+                    var_dict['val'] = _convert_ndarray_to_support_nans_in_json(
+                        vec._abs_get_val(name, flat=False))
+                else:
+                    var_dict['val'] = _convert_ndarray_to_support_nans_in_json(
+                        system.get_val(prom, from_src=False))
         else:
             var_dict['val'] = None
+    else:  # discrete
+        meta = system._var_discrete[typ][name]
+        val = meta['val']
+        var_dict = {
+            'name': name,
+            'type': typ,
+            'dtype': type(val).__name__,
+            'is_discrete': True,
+        }
+        if MPI is None or isinstance(val, (int, str, list, dict, complex, np.ndarray)):
+            var_dict['val'] = default_noraise(system.get_val(name))
+        else:
+            var_dict['val'] = type(val).__name__
+
+    if 'surrogate_name' in meta:
+        var_dict['surrogate_name'] = meta['surrogate_name']
 
     return var_dict
 
@@ -165,65 +185,38 @@ def _serialize_single_option(option):
     object
        JSON-safe serialized object.
     """
-    val = option['val']
     if not option['recordable']:
-        serialized_option = 'Not Recordable'
-    elif val is _UNDEFINED:
-        serialized_option = str(val)
-    else:
-        serialized_option = default_noraise(val)
+        return 'Not Recordable'
 
-    return serialized_option
+    val = option['val']
+    if val is _UNDEFINED:
+        return str(val)
+
+    return default_noraise(val)
 
 
-def _get_tree_dict(system, component_execution_orders, component_execution_index,
-                   is_parallel=False):
+def _get_tree_dict(system, is_parallel=False):
     """Get a dictionary representation of the system hierarchy."""
-    tree_dict = {}
-    tree_dict['name'] = system.name
-    tree_dict['type'] = 'subsystem'
-    tree_dict['class'] = system.__class__.__name__
-    tree_dict['expressions'] = None
+    tree_dict = {
+        'name': system.name if system.name else 'root',
+        'type': 'subsystem' if system.name else 'root',
+        'class': system.__class__.__name__,
+        'expressions': None,
+        'nonlinear_solver': "",
+        'nonlinear_solver_options': None,
+        'linear_solver': "",
+        'linear_solver_options': None,
+    }
+    is_implicit = False
 
-    if not isinstance(system, Group):
-        tree_dict['subsystem_type'] = 'component'
-        tree_dict['is_parallel'] = is_parallel
-        if isinstance(system, ImplicitComponent):
-            tree_dict['component_type'] = 'implicit'
-        elif isinstance(system, ExecComp):
-            tree_dict['component_type'] = 'exec'
-            tree_dict['expressions'] = system._exprs
-        elif isinstance(system, (MetaModelStructuredComp, MetaModelUnStructuredComp)):
-            tree_dict['component_type'] = 'metamodel'
-        elif isinstance(system, IndepVarComp):
-            tree_dict['component_type'] = 'indep'
-        elif isinstance(system, ExplicitComponent):
-            tree_dict['component_type'] = 'explicit'
-        else:
-            tree_dict['component_type'] = None
-
-        component_execution_orders[system.pathname] = component_execution_index[0]
-        component_execution_index[0] += 1
-
-        children = []
-        for typ in ['input', 'output']:
-            for abs_name in system._var_abs2meta[typ]:
-                children.append(_get_var_dict(system, typ, abs_name, is_parallel))
-
-            for prom_name in system._var_discrete[typ]:
-                children.append(_get_var_dict(system, typ, prom_name, is_parallel))
-
-    else:
-        if isinstance(system, ParallelGroup):
+    if isinstance(system, Group):
+        if MPI and isinstance(system, ParallelGroup):
             is_parallel = True
         tree_dict['component_type'] = None
         tree_dict['subsystem_type'] = 'group'
         tree_dict['is_parallel'] = is_parallel
 
-        children = []
-        for s in system._subsystems_myproc:
-            children.append(_get_tree_dict(s, component_execution_orders,
-                            component_execution_index, is_parallel))
+        children = [_get_tree_dict(s, is_parallel) for s in system._subsystems_myproc]
 
         if system.comm.size > 1:
             if system._subsystems_myproc:
@@ -236,68 +229,82 @@ def _get_tree_dict(system, component_execution_orders, component_execution_index
             for children_list in children_lists:
                 children.extend(children_list)
 
-    if isinstance(system, ImplicitComponent):
-        if overrides_method('solve_linear', system, ImplicitComponent):
-            tree_dict['linear_solver'] = "solve_linear"
-            tree_dict['linear_solver_options'] = None
-        elif system.linear_solver:
-            tree_dict['linear_solver'] = system.linear_solver.SOLVER
-            options = {k: _serialize_single_option(system.linear_solver.options._dict[k])
-                       for k in system.linear_solver.options}
-            tree_dict['linear_solver_options'] = options
-        else:
-            tree_dict['linear_solver'] = ""
-            tree_dict['linear_solver_options'] = None
-
-        if overrides_method('solve_nonlinear', system, ImplicitComponent):
-            tree_dict['nonlinear_solver'] = "solve_nonlinear"
-            tree_dict['nonlinear_solver_options'] = None
-        elif system.nonlinear_solver:
-            tree_dict['nonlinear_solver'] = system.nonlinear_solver.SOLVER
-            options = {k: _serialize_single_option(system.nonlinear_solver.options._dict[k])
-                       for k in system.nonlinear_solver.options}
-            tree_dict['nonlinear_solver_options'] = options
-        else:
-            tree_dict['nonlinear_solver'] = ""
-            tree_dict['nonlinear_solver_options'] = None
-    else:
         if system.linear_solver:
             tree_dict['linear_solver'] = system.linear_solver.SOLVER
-            options = {k: _serialize_single_option(system.linear_solver.options._dict[k])
-                       for k in system.linear_solver.options}
-            tree_dict['linear_solver_options'] = options
-        else:
-            tree_dict['linear_solver'] = ""
-            tree_dict['linear_solver_options'] = None
+            tree_dict['linear_solver_options'] = {
+                k: _serialize_single_option(opt)
+                for k, opt in system.linear_solver.options._dict.items()
+            }
 
         if system.nonlinear_solver:
             tree_dict['nonlinear_solver'] = system.nonlinear_solver.SOLVER
-            options = {k: _serialize_single_option(system.nonlinear_solver.options._dict[k])
-                       for k in system.nonlinear_solver.options}
-            tree_dict['nonlinear_solver_options'] = options
+            tree_dict['nonlinear_solver_options'] = {
+                k: _serialize_single_option(opt)
+                for k, opt in system.nonlinear_solver.options._dict.items()
+            }
 
             if system.nonlinear_solver.SOLVER == NewtonSolver.SOLVER:
                 tree_dict['solve_subsystems'] = system._nonlinear_solver.options['solve_subsystems']
+    else:
+        tree_dict['subsystem_type'] = 'component'
+        tree_dict['is_parallel'] = is_parallel
+        if isinstance(system, ImplicitComponent):
+            is_implicit = True
+            tree_dict['component_type'] = 'implicit'
+            if overrides_method('solve_linear', system, ImplicitComponent):
+                tree_dict['linear_solver'] = "solve_linear"
+            elif system.linear_solver:
+                tree_dict['linear_solver'] = system.linear_solver.SOLVER
+                tree_dict['linear_solver_options'] = {
+                    k: _serialize_single_option(opt)
+                    for k, opt in system.linear_solver.options._dict.items()
+                }
+
+            if overrides_method('solve_nonlinear', system, ImplicitComponent):
+                tree_dict['nonlinear_solver'] = "solve_nonlinear"
+            elif system.nonlinear_solver:
+                tree_dict['nonlinear_solver'] = system.nonlinear_solver.SOLVER
+                tree_dict['nonlinear_solver_options'] = {
+                    k: _serialize_single_option(opt)
+                    for k, opt in system.nonlinear_solver.options._dict.items()
+                }
+        elif isinstance(system, ExecComp):
+            tree_dict['component_type'] = 'exec'
+            tree_dict['expressions'] = system._exprs
+        elif isinstance(system, (MetaModelStructuredComp, MetaModelUnStructuredComp)):
+            tree_dict['component_type'] = 'metamodel'
+        elif isinstance(system, IndepVarComp):
+            tree_dict['component_type'] = 'indep'
+        elif isinstance(system, ExplicitComponent):
+            tree_dict['component_type'] = 'explicit'
         else:
-            tree_dict['nonlinear_solver'] = ""
-            tree_dict['nonlinear_solver_options'] = None
+            tree_dict['component_type'] = None
+
+        children = []
+        for typ in ['input', 'output']:
+            for abs_name in system._var_abs2meta[typ]:
+                children.append(_get_var_dict(system, typ, abs_name, is_parallel, is_implicit))
+
+            for prom_name in system._var_discrete[typ]:
+                children.append(_get_var_dict(system, typ, prom_name, is_parallel, is_implicit))
 
     tree_dict['children'] = children
 
     options = {}
-    for k in system.options:
+    slv = {'linear_solver', 'nonlinear_solver'}
+    for k, opt in system.options._dict.items():
         # need to handle solvers separate because they are classes or instances
-        if k in ['linear_solver', 'nonlinear_solver']:
-            options[k] = system.options[k].SOLVER
+        if k in slv:
+            try:
+                options[k] = opt['val'].SOLVER
+            except KeyError:
+                options[k] = opt['value'].SOLVER
+
         else:
-            options[k] = _serialize_single_option(system.options._dict[k])
+            options[k] = _serialize_single_option(opt)
 
     tree_dict['options'] = options
 
-    if not tree_dict['name']:
-        tree_dict['name'] = 'root'
-        tree_dict['type'] = 'root'
-
     return tree_dict
 
 
@@ -366,7 +373,7 @@ def _get_viewer_data(data_source, case_id=None):
         driver_options = {key: _serialize_single_option(driver.options._dict[key])
                           for key in driver.options}
 
-        if driver_type == 'optimization' and 'opt_settings' in dir(driver):
+        if driver_type == 'optimization' and hasattr(driver, 'opt_settings'):
             driver_opt_settings = driver.opt_settings
         else:
             driver_opt_settings = None
@@ -436,61 +443,73 @@ def _get_viewer_data(data_source, case_id=None):
                         "The source must be a Problem, model or the filename of a recording.")
 
     data_dict = {}
-    comp_exec_idx = [0]  # list so pass by ref
-    orders = {}
-    data_dict['tree'] = _get_tree_dict(root_group, orders, comp_exec_idx)
+    data_dict['tree'] = _get_tree_dict(root_group)
     data_dict['md5_hash'] = root_group._generate_md5_hash()
 
     connections_list = []
 
-    sys_pathnames_list = []  # list of pathnames of systems found in cycles
-    sys_pathnames_dict = {}  # map of pathnames to index of pathname in list
+    sys_idx = {}  # map of pathnames to index of pathname in list (systems in cycles only)
 
     G = root_group.compute_sys_graph(comps_only=True)
 
     scc = nx.strongly_connected_components(G)
 
-    for strong_comp in scc:
+    strongdict = {}
+
+    for i, strong_comp in enumerate(scc):
+        for c in strong_comp:
+            strongdict[c] = i  # associate each comp with a strongly connected component
+
         if len(strong_comp) > 1:
             # these IDs are only used when back edges are present
-            sys_pathnames_list.extend(strong_comp)
             for name in strong_comp:
-                sys_pathnames_dict[name] = len(sys_pathnames_dict)
+                sys_idx[name] = len(sys_idx)
 
-        for src, tgt in G.edges(strong_comp):
-            if src in strong_comp and tgt in strong_comp:
-                if src in orders:
-                    exe_src = orders[src]
-                else:
-                    exe_src = orders[src] = -1
-                if tgt in orders:
-                    exe_tgt = orders[tgt]
-                else:
-                    exe_tgt = orders[tgt] = -1
+    comp_orders = {name: i for i, name in enumerate(root_group._ordered_comp_name_iter())}
 
-                if exe_tgt < exe_src:
-                    exe_low = exe_tgt
-                    exe_high = exe_src
-                else:
-                    exe_low = exe_src
-                    exe_high = exe_tgt
+    # 1 is added to the indices of all edges in the matrix so that we can use 0 entries to
+    # indicate that there is no connection.
+    matrix = np.zeros((len(comp_orders), len(comp_orders)), dtype=np.int32)
+    edge_ids = []
+    for i, edge in enumerate(G.edges()):
+        src, tgt = edge
+        if strongdict[src] == strongdict[tgt]:
+            matrix[comp_orders[src], comp_orders[tgt]] = i + 1  # bump edge index by 1
+            edge_ids.append((sys_idx[src], sys_idx[tgt]))
+        else:
+            edge_ids.append(None)
 
-                edges_list = [
-                    (sys_pathnames_dict[s], sys_pathnames_dict[t]) for s, t in G.edges(strong_comp)
-                    if s in orders and exe_low <= orders[s] <= exe_high and t in orders and
-                    exe_low <= orders[t] <= exe_high and
-                    not (s == src and t == tgt) and t in sys_pathnames_dict
-                ]
+    for edge_i, (src, tgt) in enumerate(G.edges()):
+        if strongdict[src] == strongdict[tgt]:
+            start = comp_orders[src]
+            end = comp_orders[tgt]
+            # get a view here so we can remove this edge from submat temporarily to eliminate
+            # an 'if' check inside the nested list comprehension for edges_list
+            rem = matrix[start:start + 1, end:end + 1]
+            rem[0, 0] = 0
+
+            if end < start:
+                start, end = end, start
+
+            submat = matrix[start:end + 1, start:end + 1]
+            nz = submat[submat > 0]
+
+            rem[0, 0] = edge_i + 1  # put removed edge back
+
+            if nz.size > 1:
+                nz -= 1  # convert back to correct edge index
+                edges_list = [edge_ids[i] for i in nz]
                 for vsrc, vtgtlist in G.get_edge_data(src, tgt)['conns'].items():
                     for vtgt in vtgtlist:
                         connections_list.append({'src': vsrc, 'tgt': vtgt,
                                                  'cycle_arrows': edges_list})
-            else:  # edge is out of the SCC
-                for vsrc, vtgtlist in G.get_edge_data(src, tgt)['conns'].items():
-                    for vtgt in vtgtlist:
-                        connections_list.append({'src': vsrc, 'tgt': vtgt})
+                continue
 
-    data_dict['sys_pathnames_list'] = sys_pathnames_list
+        for vsrc, vtgtlist in G.get_edge_data(src, tgt)['conns'].items():
+            for vtgt in vtgtlist:
+                connections_list.append({'src': vsrc, 'tgt': vtgt})
+
+    data_dict['sys_pathnames_list'] = list(sys_idx)
     data_dict['connections_list'] = connections_list
     data_dict['abs2prom'] = root_group._var_abs2prom
 
