@@ -31,7 +31,7 @@ class N2UserInterface {
         this.backButtonHistory = [];
         this.forwardButtonHistory = [];
 
-        this._setupCollapseDepthElement();
+        this._setupCollapseDepthSlider();
         this.updateClickedIndices();
         this._setupSearch();
         this._setupResizerDrag();
@@ -98,24 +98,46 @@ class N2UserInterface {
             }
             fr.readAsText(this.files[0]);
         })
-
     }
 
+    /**
+     * Set the range and current value of the collapse depth slider.
+     * @param {Number} opts.min The shallowest elements to allow to collapse via slider.
+     * @param {Number} opts.max The deepest elements to allow to collapse via slider.
+     * @param {Number} opts.val The current slider collapse depth value.
+     */
+    setCollapseDepthSlider(opts = {}) {
+        const min = opts.min ? opts.min : 2;
+        const max = opts.max ? opts.max : this.n2Diag.model.maxDepth;
+        const val = opts.val ? opts.val : max;
+
+        this.collapseDepthSlider
+            .property('min', min)
+            .property('max', max)
+            .property('value', val);
+
+        this.collapseDepthLabel.text(val);
+    }
+
+    get collapseDepthSliderVal() { return Number(this.collapseDepthSlider.property('value')); }
+
     /** Set up the menu for selecting an arbitrary depth to collapse to. */
-    _setupCollapseDepthElement() {
-        let self = this;
+    _setupCollapseDepthSlider() {
+        const self = this;
 
-        let collapseDepthElement = this.n2Diag.dom.parentDiv.querySelector(
-            '#depth-slider'
-        );
+        this.collapseDepthSlider = d3.select('input#depth-slider'),
+            this.collapseDepthLabel = d3.select('p#depth-slider-label');
 
-        collapseDepthElement.max = this.n2Diag.model.maxDepth - 1;
-        collapseDepthElement.value = collapseDepthElement.max;
+        this.setCollapseDepthSlider();
 
-        collapseDepthElement.onmouseup = function (e) {
-            const modelDepth = parseInt(e.target.value);
-            self.collapseToDepthSelectChange(modelDepth);
-        };
+        this.collapseDepthSlider
+            .on('mouseup', e => {
+                const val = self.collapseDepthSlider.property('value');
+                self.collapseToDepth(val);
+            })
+            .on('input', e => {
+                self.collapseDepthLabel.text(self.collapseDepthSliderVal);
+            });
     }
 
     /** Set up event handlers for grabbing the bottom corner and dragging */
@@ -179,7 +201,7 @@ class N2UserInterface {
                         .on('mousemove', null)
                         .on('mouseup', null);
                 })
-                .on('mousemove', e => {
+                .on('input', e => {
                     const newHeight = d3.event.clientY - offset.y;
                     if (newHeight + n2Diag.layout.gapDist * 2 >= window.innerHeight * .5) {
                         newDims = {
@@ -368,7 +390,8 @@ class N2UserInterface {
         this.backButtonHistory.push({
             'node': this.n2Diag.zoomedElement,
             'hidden': formerHidden,
-            'search': this.toolbar.getSearchState()
+            'search': this.toolbar.getSearchState(),
+            'collapseDepth': this.currentCollapseDepth
         });
 
         if (clearForward) this.forwardButtonHistory = [];
@@ -386,7 +409,8 @@ class N2UserInterface {
         this.forwardButtonHistory.push({
             'node': node,
             'hidden': formerHidden,
-            'search': this.toolbar.getSearchState()
+            'search': this.toolbar.getSearchState(),
+            'collapseDepth': this.currentCollapseDepth
         });
     }
 
@@ -411,6 +435,7 @@ class N2UserInterface {
         const node = history.node;
 
         this.toolbar.setSearchState(history.search);
+        this.setCollapseDepthSlider({ 'val': history.collapseDepth });
 
         // Check to see if the node is a collapsed node or not
         if (node.collapsable) {
@@ -453,6 +478,7 @@ class N2UserInterface {
         const node = history.node;
 
         this.toolbar.setSearchState(history.search);
+        this.setCollapseDepthSlider({ 'val': history.collapseDepth });
 
         d3.select('#redo-graph').classed('disabled-button',
             (this.forwardButtonHistory.length == 0));
@@ -516,6 +542,7 @@ class N2UserInterface {
         this.leftClickIsForward = false;
         this.findRootOfChangeFunction = this.findRootOfChangeForCollapseUncollapseOutputs;
         this.addBackButtonHistory();
+        this.setCollapseDepthSlider();
 
         this.n2Diag.reset();
     }
@@ -610,14 +637,14 @@ class N2UserInterface {
     }
 
     /**
-     * React to a new selection in the collapse-to-depth drop-down.
-     * @param {Number} newChosenCollapseDepth Selected depth to collapse to.
+     * React to a new selection in the collapse-to-depth toolbar slider.
+     * @param {Number} depth Selected depth to collapse to.
      */
-    collapseToDepthSelectChange(newChosenCollapseDepth) {
-        testThis(this, 'N2UserInterface', 'collapseToDepthSelectChange');
+    collapseToDepth(depth) {
+        testThis(this, 'N2UserInterface', 'collapseToDepth');
 
         this.addBackButtonHistory();
-        this.n2Diag.minimizeToDepth(newChosenCollapseDepth);
+        this.n2Diag.minimizeToDepth(depth);
         this.findRootOfChangeFunction = this.findRootOfChangeForCollapseDepth.bind(
             this
         );
@@ -729,6 +756,8 @@ class N2UserInterface {
     update() {
         testThis(this, 'N2UserInterface', 'update');
 
+        this.currentCollapseDepth = this.collapseDepthSliderVal;
+
         d3.select('#undo-graph').classed('disabled-button',
             (this.backButtonHistory.length == 0));
         d3.select('#redo-graph').classed('disabled-button',
